@@ -13,8 +13,15 @@ class Component(Base):
     self._options = Helper.opt_parser()
 
     if(self._options["command"] == "info"):
-      sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-      sock.connect((self._options["host"], int(self._options["port"])))
+      
+      sock = None
+      if (self._options["host"] is not None):
+        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        sock.connect((self._options["host"], int(self._options["port"])))
+      elif (self._options["unix_socket"] is not None):
+        sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
+        sock.connect(self._options["unix_socket"])
+
       self._socket = sock.makefile()
       Helper.write_hash_to_file({"language":"python", "name":self._name, "flow_type":"component", "multilang_version":VERSION}, self._socket)
 
